Package: forcis
Type: Package
Title: Handle the FORCIS Foraminifera Database
Version: 1.0.1
Authors@R: c(
    person(given   = "Nicolas",
           family  = "Casajus",
           role    = c("aut", "cre", "cph"),
           email   = "nicolas.casajus@fondationbiodiversite.fr",
           comment = c(ORCID = "0000-0002-5537-5294")),
    person(given   = "Mattia",
           family  = "Greco",
           role    = "aut",
           email   = "mattia_greco@outlook.com",
           comment = c(ORCID = "0000-0003-2416-6235")),
    person(given   = "Sonia",
           family  = "Chaabane",
           role    = "aut",
           email   = "sonia.chaabane@gmail.com",
           comment = c(ORCID = "0000-0002-4653-8610")),
    person(given   = "Xavier",
           family  = "Giraud",
           role    = "aut",
           email   = "giraud@cerege.fr",
           comment = c(ORCID = "0000-0001-5067-8176")),
    person(given   = "Thibault",
           family  = "de Garidel-Thoron",
           role    = "aut",
           email   = "garidel@cerege.fr",
           comment = c(ORCID = "0000-0001-8983-9571")),
    person(given   = "Khalil",
           family  = "Hammami",
           role    = "ctb",
           email   = "khalil.hammami@enetcom.usf.tn"),
    person(given   = "Air",
           family  = "Forbes",
           role    = "rev",
           email   = "amforbes@ualberta.ca",
           comment = c(ORCID = "0000-0002-9842-7648")),
    person(given   = "FRB-CESAB",
           role    = "fnd"))
Description: Provides an interface to the 'FORCIS' database 
    (Chaabane et al. (2024) <doi:10.5281/zenodo.7390791>) on global foraminifera
    distribution. This package allows to download and to handle 'FORCIS' data.
    It is part of the FRB-CESAB working group FORCIS.
    <https://www.fondationbiodiversite.fr/en/the-frb-in-action/programs-and-projects/le-cesab/forcis/>.
URL: https://docs.ropensci.org/forcis/,
        https://github.com/ropensci/forcis
BugReports: https://github.com/ropensci/forcis/issues
License: GPL (>= 2)
Encoding: UTF-8
RoxygenNote: 7.3.2
VignetteBuilder: knitr
Depends: R (>= 4.1.0)
Imports: ggplot2, httr2, rlang, sf, tibble, tidyr, utils, vroom
Suggests: fs, dplyr, httptest2, knitr, rmarkdown, testthat (>= 3.0.0),
        vdiffr, withr
Config/testthat/edition: 3
NeedsCompilation: no
Packaged: 2025-05-20 09:26:48 UTC; nicolas
Author: Nicolas Casajus [aut, cre, cph] (ORCID:
    <https://orcid.org/0000-0002-5537-5294>),
  Mattia Greco [aut] (ORCID: <https://orcid.org/0000-0003-2416-6235>),
  Sonia Chaabane [aut] (ORCID: <https://orcid.org/0000-0002-4653-8610>),
  Xavier Giraud [aut] (ORCID: <https://orcid.org/0000-0001-5067-8176>),
  Thibault de Garidel-Thoron [aut] (ORCID:
    <https://orcid.org/0000-0001-8983-9571>),
  Khalil Hammami [ctb],
  Air Forbes [rev] (ORCID: <https://orcid.org/0000-0002-9842-7648>),
  FRB-CESAB [fnd]
Maintainer: Nicolas Casajus <nicolas.casajus@fondationbiodiversite.fr>
Repository: CRAN
Date/Publication: 2025-05-23 12:02:02 UTC
Built: R 4.6.0; ; 2026-04-29 17:52:46 UTC; unix
